@@ -1,16 +1,16 @@
 //! This module contains a generic `Tracer`'s methods.
 use crate::actors::connector;
-use crate::actors::pool::{self, RillPoolTask};
+//use crate::actors::pool::{self, RillPoolTask};
 use anyhow::Error;
-use async_trait::async_trait;
-use futures::channel::mpsc;
+//use async_trait::async_trait;
+//use futures::channel::mpsc;
 use meio::Action;
 use rill_protocol::flow::core::{self, ActionEnvelope, TimedEvent};
 use rill_protocol::io::provider::{Description, Path, ProviderProtocol, Timestamp};
 use rill_protocol::io::transport::Direction;
 use std::sync::{Arc, Mutex, Weak};
 use std::time::{Duration, SystemTime};
-use tokio::sync::{broadcast, watch};
+use tokio::sync::{mpsc, watch};
 
 #[derive(Debug)]
 pub(crate) struct EventEnvelope<T: core::Flow> {
@@ -24,8 +24,10 @@ impl<T: core::Flow> Action for EventEnvelope<T> {}
 pub(crate) type DataSender<T> = mpsc::UnboundedSender<EventEnvelope<T>>;
 pub(crate) type DataReceiver<T> = mpsc::UnboundedReceiver<EventEnvelope<T>>;
 
+pub(crate) type ControlSender<T> = mpsc::UnboundedSender<ActionEnvelope<T>>;
+
 /// Watches for the control events.
-pub type Watcher<T> = broadcast::Receiver<ActionEnvelope<T>>;
+pub type Watcher<T> = mpsc::UnboundedReceiver<ActionEnvelope<T>>;
 
 pub(crate) enum TracerMode<T: core::Flow> {
     /* TODO: THE Idea to implement storage:
@@ -42,8 +44,8 @@ pub(crate) enum TracerMode<T: core::Flow> {
     Push {
         state: T,
         receiver: Option<DataReceiver<T>>,
-        /// For sending events to a `Tracer` instances
-        control_sender: broadcast::Sender<ActionEnvelope<T>>,
+        /// For sending events to the `Tracer` instance
+        control_sender: Option<ControlSender<T>>,
     },
     /// Pulling for intensive streams with high-load activities
     Pull {
@@ -54,26 +56,16 @@ pub(crate) enum TracerMode<T: core::Flow> {
 
 #[derive(Debug)]
 enum InnerMode<T: core::Flow> {
-    Push {
-        sender: DataSender<T>,
-        /// Kept for generating new `Receiver`s
-        control_sender: Arc<broadcast::Sender<ActionEnvelope<T>>>,
-    },
-    Pull {
-        state: Arc<Mutex<T>>,
-    },
+    Push { sender: DataSender<T> },
+    Pull { state: Arc<Mutex<T>> },
 }
 
 // TODO: Or require `Clone` for the `Flow` to derive this
 impl<T: core::Flow> Clone for InnerMode<T> {
     fn clone(&self) -> Self {
         match self {
-            Self::Push {
-                sender,
-                control_sender,
-            } => Self::Push {
+            Self::Push { sender } => Self::Push {
                 sender: sender.clone(),
-                control_sender: control_sender.clone(),
             },
             Self::Pull { state } => Self::Pull {
                 state: state.clone(),
@@ -116,17 +108,14 @@ impl<T: core::Flow> Eq for Tracer<T> {}
 impl<T: core::Flow> Tracer<T> {
     /// Create a `Push` mode `Tracer`
     pub fn new_push(state: T, path: Path) -> (Self, Watcher<T>) {
-        let (tx, rx) = mpsc::unbounded();
-        let (control_tx, control_rx) = broadcast::channel(16);
+        let (tx, rx) = mpsc::unbounded_channel();
+        let (control_tx, control_rx) = mpsc::unbounded_channel();
         let mode = TracerMode::Push {
             state,
             receiver: Some(rx),
-            control_sender: control_tx.clone(),
-        };
-        let inner_mode = InnerMode::Push {
-            sender: tx,
-            control_sender: Arc::new(control_tx),
+            control_sender: Some(control_tx),
         };
+        let inner_mode = InnerMode::Push { sender: tx };
         (Self::new_inner(path, inner_mode, mode), control_rx)
     }
 
@@ -179,7 +168,7 @@ impl<T: core::Flow> Tracer<T> {
                 InnerMode::Push { sender, .. } => {
                     let envelope = EventEnvelope { direction, event };
                     // And will never send an event
-                    if let Err(err) = sender.unbounded_send(envelope) {
+                    if let Err(err) = sender.send(envelope) {
                         log::error!("Can't transfer data to sender: {}", err);
                     }
                 }
@@ -200,6 +189,7 @@ impl<T: core::Flow> Tracer<T> {
         }
     }
 
+    /*
     /// Subscribe to the stream of the watcher.
     pub fn subscribe(&mut self) -> Result<Watcher<T>, Error> {
         match &mut self.mode {
@@ -210,7 +200,9 @@ impl<T: core::Flow> Tracer<T> {
             }
         }
     }
+    */
 
+    /*
     /// Registers a callback to the flow.
     pub fn callback<F>(&mut self, func: F)
     where
@@ -227,8 +219,10 @@ impl<T: core::Flow> Tracer<T> {
             );
         }
     }
+    */
 }
 
+/*
 struct Callback<T: core::Flow, F> {
     tracer: Tracer<T>,
     callback: F,
@@ -248,6 +242,7 @@ where
         }
     }
 }
+*/
 
 impl<T: core::Flow> Tracer<T> {
     /// Returns `true` is the `Tracer` has to send data.
